@@ -1,7 +1,7 @@
 # WWW::OPG
 #  Perl interface to Ontario Power Generation's site
 #
-# $Id: OPG.pm 10704 2010-01-01 01:28:37Z FREQUENCY@cpan.org $
+# $Id: OPG.pm 10933 2010-01-11 03:15:58Z FREQUENCY@cpan.org $
 
 package WWW::OPG;
 
@@ -18,18 +18,13 @@ WWW::OPG - Perl interface to Ontario Power Generation's site
 
 =head1 VERSION
 
-Version 1.003 ($Id: OPG.pm 10704 2010-01-01 01:28:37Z FREQUENCY@cpan.org $)
+Version 1.004 ($Id: OPG.pm 10933 2010-01-11 03:15:58Z FREQUENCY@cpan.org $)
 
 =cut
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 $VERSION = eval $VERSION;
 
-=head1 DESCRIPTION
-
-This module provides a Perl interface to information published on Ontario
-Power Generation's web site at L<http://www.opg.com>.
-
 =head1 SYNOPSIS
 
   use WWW::OPG;
@@ -40,6 +35,13 @@ Power Generation's web site at L<http://www.opg.com>.
   };
   print "Currently generating ", $opg->power, "MW of electricity\n";
 
+=head1 DESCRIPTION
+
+This module provides a Perl interface to information published on Ontario
+Power Generation's web site at L<http://www.opg.com>. This module provides
+very quick and low-bandwidth queries using the special machine-readable file
+proffered by OPG; see L<http://www.opg.com/megafile.txt>.
+
 =head1 COMPATIBILITY
 
 This module was tested under Perl 5.10.1, using Debian Linux. However, because
@@ -117,20 +119,18 @@ sub poll {
   Carp::croak('You must call this method as an object') unless ref($self);
 
   my $ua = $self->{useragent};
-  my $r = $ua->get('http://www.opg.com/');
+  my $r = $ua->get('http://www.opg.com/megafile.txt');
 
   Carp::croak('Error reading response: ' . $r->status_line)
     unless $r->is_success;
 
-  if ($r->content =~ m{
-      ([0-9]+),?([0-9]+)</span><span\ class='wht'>\ MW</span>
-    }x)
+  my ($power, $date) = split(chr(13) . chr(10), $r->content);
+
+  if ($power =~ m{^([0-9]+),?([0-9]+)$})
   {
     $self->{power} = $1 . $2;
 
-    if ($r->content =~ m{
-        Last\ updated:\ (\d+)/(\d+)/(\d+)\ (\d+):(\d+):(\d+)\ (AM|PM)  
-      }x)
+    if ($date =~ m{^(\d+)/(\d+)/(\d+) (\d+):(\d+):(\d+) (AM|PM)})
     {
       my $hour = $4;
       # 12:00 noon and midnight are a special case
@@ -224,6 +224,20 @@ Jonathan Yu E<lt>jawnsy@cpan.orgE<gt>
 
 Your name here ;-)
 
+=head1 ACKNOWLEDGEMENTS
+
+=over
+
+=item *
+
+Thanks to the kind folks at OPG and in particular someone I know only as
+"Rose" E<lt>webmaster@opg.comE<gt> for providing me with an API in the form
+of a small text file which provides the same data as that scraped from the
+web page itself. This cuts down significantly on bandwidth costs and the
+time it takes to check the data.
+
+=back
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
